# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class ForecastRow(UniversalBaseModel):
    timestamp: dt.datetime = pydantic.Field()
    """
    UTC valid‑time of the forecast
    """

    asset_name: str = pydantic.Field()
    """
    Asset name
    """

    asset_id: int = pydantic.Field()
    """
    Asset id
    """

    latitude: float
    longitude: float
    variable: str
    value: float

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
