# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel, update_forward_refs
from .feature_geometry import FeatureGeometry
from .feature_id import FeatureId
from .feature_properties import FeatureProperties


class Feature(UniversalBaseModel):
    """
    Feature Model
    """

    bbox: typing.Optional[typing.List[typing.Optional[typing.Any]]] = None
    type: typing.Literal["Feature"] = "Feature"
    geometry: typing.Optional[FeatureGeometry] = None
    properties: typing.Optional[FeatureProperties] = None
    id: typing.Optional[FeatureId] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


from .geometry_collection import GeometryCollection  # noqa: E402, F401, I001

update_forward_refs(Feature)
